@@ -464,8 +464,8 @@ write("4. Pre- and post-multiply NTginvATN by block projection matrices.", "")
   }
   
   
-  VC <-character(length(V))
-   names(VC)  = names(V)
+  VC <-rep("1",length(V)+1)
+   names(VC)  = c("DF", names(V))
    VC = t(data.frame(VC))
  ##############################################################################################################  
 write("5. Get coefficients of each source of variation for the random effects,", "")
@@ -481,13 +481,17 @@ write("5. Get coefficients of each source of variation for the random effects,",
       
       
        if(nrow(tmp) == 1 && rownames(tmp) == "Residual"){
-         tmp = c(tmp[1], tmp[-1]/tmp[1])  
+         tmp = c(tmp[1], tmp/tmp[1])  
          VC = rbind(VC, attr(fractions(tmp),"fracs"))
           
-         rownames(VC)[nrow(VC)] = paste("Between", names(PNTginvATNP[i]), sep = " ")
+        if(names(PNTginvATNP[i]) == "Within"){
+          rownames(VC)[nrow(VC)] =  paste(names(PNTginvATNP[i]), sep = " ")
+        }else{
+          rownames(VC)[nrow(VC)] = paste("Between", names(PNTginvATNP[i]), sep = " ")
+        }
  
        }else{
-        VC = rbind(VC, character(length = length(V)))
+        VC = rbind(VC, character(length = length(V) + 1))
           
         if(names(PNTginvATNP[i]) == "Within"){
           rownames(VC)[nrow(VC)] =  paste(names(PNTginvATNP[i]), sep = " ")
@@ -497,13 +501,17 @@ write("5. Get coefficients of each source of variation for the random effects,",
         
         rownames(tmp) = paste("  ", rownames(tmp), sep = " ")
         
-        tmp = t(apply(tmp, 1, function(x) attr(fractions(c(x[1], x[-1]/x[1])),"fracs")))
+        tmp = t(apply(tmp, 1, function(x) attr(fractions(c(x[1], x/x[1])),"fracs")))
         VC = rbind(VC, tmp)
       }           
       
     }
-   colnames(VC)[1] = "DF"
-   VC = noquote(VC[-1,])   
+     
+   if(length((which(apply(apply(VC[,-1], 2, function(x) x==VC[,"e"]), 2, all))))>1){   
+    VC = noquote(VC[-1,-2])
+   } else{
+    VC = noquote(VC[-1,])   
+   }
     
    if(table.legend){
     Legend = paste(paste( letters[1:(length(colnames(VC))-1)],colnames(VC)[-1], sep = " = "))
